@@ -34,7 +34,7 @@
 
 namespace fs = std::filesystem;
 
-using json = zeep::json::element;
+using json = nlohmann::json;
 
 // --------------------------------------------------------------------
 // simple integer compression, based somewhat on MRS code
@@ -282,7 +282,7 @@ void DecompressSimpleArraySelector(IBitStream &inBits, std::vector<uint32_t> &ou
 	uint32_t width = kStartWidth;
 	uint32_t span = 0;
 
-	// The array should be initilialized to the expected size!
+	// The array should be initialized to the expected size!
 	auto size = outArray.size();
 	auto a = outArray.begin();
 
@@ -588,6 +588,9 @@ void buildDataFile(const fs::path &dir)
 {
 	using namespace std::literals;
 
+	if constexpr (std::endian::native == std::endian::big)
+		throw std::logic_error("Sorry, this code works on little endian machines only");
+
 	// first read the global mean and sd
 
 	float mean_torsion, sd_torsion, mean_ramachandran, sd_ramachandran;
@@ -794,6 +797,21 @@ const Data &DataTable::loadRamachandranData(const std::string &aa, SecStrType ss
 	return *i;
 }
 
+template <typename T>
+void byteswap(T &v)
+{
+	T result;
+
+	char *pv = (char *)&v;
+	char *presult = (char *)&result;
+	int size = sizeof(T);
+
+	for (int i = 0; i < size; i++)
+		presult[size - 1 - i] = pv[i];
+
+	v = result;
+}
+
 void DataTable::load(const char *name, std::vector<Data> &table, float &mean, float &sd)
 {
 	using namespace std::literals;
@@ -807,13 +825,20 @@ void DataTable::load(const char *name, std::vector<Data> &table, float &mean, fl
 	auto size = rfd->tellg();
 	rfd->seekg(0, rfd->beg);
 
-	const float *fv = new float[size / sizeof(float) + 1];
-	rfd->read(reinterpret_cast<char *>(const_cast<float *>(fv)), size);
-
+	float *fv = new float[size / sizeof(float) + 1];
+	rfd->read(reinterpret_cast<char *>(fv), size);
+	
 	mean = fv[0];
 	sd = fv[1];
 
-	const StoredData *data = reinterpret_cast<const StoredData *>(fv + 2);
+	StoredData *data = reinterpret_cast<StoredData *>(fv + 2);
+
+	if constexpr (std::endian::native == std::endian::big)
+	{
+		byteswap(mean);
+		byteswap(sd);
+	}
+
 	size_t ix = 0;
 	while (data[ix].aa[0] != 0)
 		++ix;
@@ -822,7 +847,19 @@ void DataTable::load(const char *name, std::vector<Data> &table, float &mean, fl
 	const uint8_t *bits = reinterpret_cast<const uint8_t *>(fv + 2) + (n + 1) * sizeof(StoredData);
 
 	for (ix = 0; ix < n; ++ix)
+	{
+		if constexpr (std::endian::native == std::endian::big)
+		{
+			byteswap(data[ix].mean);
+			byteswap(data[ix].mean_vs_random);
+			byteswap(data[ix].sd);
+			byteswap(data[ix].sd_vs_random);
+			byteswap(data[ix].binSpacing);
+			byteswap(data[ix].offset);
+		}
+
 		table.emplace_back(strcmp(name, "torsion-data.bin") == 0, data[ix], bits);
+	}
 }
 
 // --------------------------------------------------------------------
